createProject method
Creates a new Firebase project with the given id.
This command runs in ProcessStartMode.inheritStdio mode to allow for interactive project name entry and real-time feedback.
Implementation
Future<void> createProject(String id) async {
await runInteractive('firebase', ['projects:create', id]);
}