FlutterService class
Service for managing Flutter-specific dependencies and commands.
Constructors
- FlutterService()
- Default constructor for FlutterService.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addDep(
String package) → Future< void> - Adds a single dependency to the project.
-
addDeps(
) → Future< void> - Adds core Firebase and FlutterFire dependencies to the project.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited