utils/process_runner library

Documentation for the process runner utility library.

Functions

getInjectedEnvironment() Map<String, String>
Generates an environment map with professional tool paths injected.
openUrl(String url) Future<void>
Opens the specified url in the system's default browser.
run(String cmd, List<String> args) Future<void>
Runs a cmd with args and returns when the process completes.
runInteractive(String cmd, List<String> args) Future<void>
Runs a cmd with args in interactive mode.
runWithResult(String cmd, List<String> args) Future<ProcessResult>
Runs a cmd with args and returns the ProcessResult.