run function
Runs a cmd with args and returns when the process completes.
This is a convenience wrapper around runWithResult.
Implementation
Future<void> run(String cmd, List<String> args) async {
await runWithResult(cmd, args);
}
Runs a cmd with args and returns when the process completes.
This is a convenience wrapper around runWithResult.
Future<void> run(String cmd, List<String> args) async {
await runWithResult(cmd, args);
}