FeatureService class
Service for managing Firebase feature activation and deactivation.
Constructors
- FeatureService()
- Default constructor for FeatureService.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disable(
String feature) → Future< void> -
Disables (or provides instructions for disabling) a
feature. -
enable(
String feature, {String? projectId}) → Future< void> -
Enables a specific Firebase
featurefor the project. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited