PromptService class
Service for handling interactive user prompts and selections.
Constructors
- PromptService()
- Default constructor for PromptService.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
ask(
String msg) → String -
Prompts the user for a text input with the given
msg. -
confirm(
String msg) → bool -
Prompts the user for a yes/no confirmation with the given
msg. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
select(
String msg, List< String> options) → int -
Prompts the user to select one option from a list of
options. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited